#[non_exhaustive]pub struct InsetLegend {
pub edge: RwSignal<Edge>,
pub legend: Legend,
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.edge: RwSignal<Edge>Edge of the chart area to place the legend.
legend: LegendLegend to display. Relies on the internal anchor signal. See Legend for details.
Implementations
Sourceimpl InsetLegend
impl InsetLegend
Sourcepub fn top_left() -> Self
pub fn top_left() -> Self
Creates a new inset legend placed at the top-left corner of the chart area.
Sourcepub fn top_right() -> Self
pub fn top_right() -> Self
Creates a new inset legend placed at the top-right corner of the chart area.
Sourcepub fn bottom_left() -> Self
pub fn bottom_left() -> Self
Creates a new inset legend placed at the bottom-left corner of the chart area.
Sourcepub fn bottom() -> Self
pub fn bottom() -> Self
Creates a new inset legend placed at the bottom-middle of the chart area.
Sourcepub fn bottom_right() -> Self
pub fn bottom_right() -> Self
Creates a new inset legend placed at the bottom-right corner of the chart area.