pub struct Padding { /* private fields */ }Expand description
Represents padding around the edges of a component.
Implementations
Sourceimpl Padding
Represents padding around a component. Note that the context matters on how it’s applied. For example, padding applied to the whole chart will shrink the available space whereas padding applied to a label will increase the size used.
impl Padding
Represents padding around a component. Note that the context matters on how it’s applied. For example, padding applied to the whole chart will shrink the available space whereas padding applied to a label will increase the size used.